% La fonction "biaisTLC" évalue par la méthode de Monte-Carlo la
% probabilité que X soit plus grande que mu+lambda*sigma, où mu et sigma
% sont les moyenne et écart-type de X. Si le théorème-limite central
% s'appliquait exactement avec un nombre fini de termes dans la somme, X
% aurait une loi gaussienne; ce qui nous intéresse, c'est de voir en quoi
% la fonction de répartition (complémentaire) de X diffère de celle d'une
% loi gaussienne. On utilise pour cela un couplage entre X et une
% gaussienne. "N" est le nombre de simulations demandées.
function biaisTLC (lambda, N)
% On va évaluer P(X>mu+lambda*sigma) - P(G>mu+lambda*sigma) par couplage
% entre X et G.
somme = 0;
somme2 = 0;
for i = 1 : N
    [X,G] = couplage;
    % Noter que les conditions booléennes qui apparaissent dans la ligne
    % suivante sont en fait interprétées par conversion de type implicite
    % comme les indicatrices des conditions en question.
    valeur = (X > 8 + 4*lambda) - (G > 8 + 4*lambda);
    somme = somme + valeur;
    somme2 = somme2 + valeur*valeur;
end
% On calcule l'intervalle de confiance pour la différence des probabilités.
moyenne = somme / N;
ecarttype = sqrt (somme2/N - moyenne*moyenne);
erreur = 1.96 * ecarttype / sqrt(N);
fprintf('Estimation de la différence entre P(X>mu+lambda*sigma) ');
fprintf('et P(N(1)>lambda) :\n');
fprintf('%.6f ± %.6f\n', moyenne, erreur);
% On sait que la probabilité que G soit plus grande que que mu+lambda*sigma
% est exactement la fonction de répartition (complémentaire) de la loi
% normale standard en lambda, soit le "pourG" donné ci-dessous.
pourG = (1 - erf (lambda / sqrt(2))) / 2;
fprintf('Soit une valeur brute pour la probabilité que X')
fprintf('soit plus grande que mu + lambda * sigma de :\n')
fprintf('%.6f ± %.6f\n', moyenne + pourG, erreur);
end