% La fonction "couplage" réalise un couplage entre la loi de X (simulée par
% "X") et une loi gaussienne de mêmes moments d'ordre 2 (simulée par
% "G"). Pour cela, écrit X comme une somme de 4 v.a. exponentielles
% indépendantes, en couplant chacune de ces v.a. avec une loi gaussienne de
% mêmes moments d'ordre 2.
function [X,G] = couplage
% "Y" va contenir quatre lois Expon(1) indépendantes.
Y = zeros(1,4);
% "Z" va contenir quatre lois N(1), chacune étant couplée à la variable Y_i
% correspondante (de sorte que ces quatre lois seront elles aussi
% indépendantes entre elles).
Z = zeros(1,4);
for i = 1 : 4
    [Y(i),Z(i)] = couplage_elem;
    % Calculs de X et G à partir des Y_i et Z_i.
    X = 2*sum(Y);
    % sum(Z) est une loi N(4); comme G doit être une loi 8+N(16), on
    % obtient G à partir de Z par la transformation affine ci-dessous.
    G = 8 + 2*sum(Z);
end
