% La fonction "sanscouplage" calcule les mêmes quantités que "biaisTLC",
% mais sans utiliser la méthode de couplage.
function sanscouplage (lambda, N)
% On va évaluer directement P(X>mu+lambda*sigma) par la méthode de
% Monte-Carlo “naïve”. Comme on évalue l'espérance d'une Bernoulli, il est
% inutile de maintenir "somme2" qui est la même chose que "somme" ; on
% utilise plutôt de nom "occurrences" pour désigner le nombre de fois où
% l'évènement s'est réalisé.
occurrences = 0;
for i = 1 : N
    % Simulation de X à partir d'une somme de lois exponentielles. "Y" est
    % un vecteur de 4 lois Expon(1) indépendantes, simulées par la méthode
    % de la fonction de répartition.
    Y = zeros(1,4);
    for k = 1 : 4
        % Noter que dans la ligne suivante, puisque "1-rand" a la même loi
        % que "rand", on aurait pu simuler directement « Y(k) = -log(rand)
        % ».
        Y(k) = -log(1-rand);
    end
    X = 2 * sum(Y);
    occurrences = occurrences + (X > 8 + 4*lambda);
end
% On calcule l'intervalle de confiance pour la différence des probabilités.
proba = occurrences / N;
% Dans le cas d'une variable de Bernoulli, l'écart-type d'exprime
% directement en fonction de la probabilité.
ecarttype = sqrt (proba * (1-proba));
erreur = 1.96 * ecarttype / sqrt(N);
fprintf('Estimation de P(X>mu+lambda*sigma) :');
fprintf('%.6f ± %.6f\n', proba, erreur);
% Soit, en termes de différence par rapport à la loi normale :
pourG = (1 - erf (lambda / sqrt(2))) / 2;
fprintf('Soit une différence avec ce qu''aurait été cette probabilité')
fprintf('pour le loi normale de :\n')
fprintf('%.6f ± %.6f\n', proba - pourG, erreur);
end